@@ -13,10 +13,11 @@ BaseMenu::BaseMenu(Display * dpy)
 
 void BaseMenu::initializeMenu(Display *d)
 {
+	XSetWindowAttributes attrib;
+	long create_mask;	
+	
 	dpy = d;
 	screen = DefaultScreen(dpy);
-	depth = DefaultDepth(dpy, screen);
-	visual = DefaultVisual(dpy, screen);
 	root = RootWindow(dpy, screen);
 
 	item_window = None;
@@ -28,8 +29,6 @@ void BaseMenu::initializeMenu(Display *d)
 	height=1;
 	total_item_height=0;
 	is_visible=false;
-	
-	curs = XCreateFontCursor(dpy, XC_left_ptr);
 		
 	direction=0;
 	ascent=0;
@@ -40,8 +39,6 @@ void BaseMenu::initializeMenu(Display *d)
 	right_edge=false;
 	item_width=0;
 	item_height=0;
-	xres=0;
-	yres=0;
 	curr=NULL;
 	enterOnce=false;	
 
@@ -88,9 +85,9 @@ void BaseMenu::initializeMenu(Display *d)
 		  	      width, 
 			      height, 
 			      1, 
-			      depth,
+			      DefaultDepth(dpy, screen),
 		  	      InputOutput, 
-			      visual, 
+			      DefaultVisual(dpy,screen), 
 			      create_mask, 
 			      &attrib
 			      );
@@ -101,8 +98,6 @@ void BaseMenu::initializeMenu(Display *d)
     	gc = XCreateGC(dpy, item_window, GCFunction|GCForeground|GCFont, &gv);
 	
 	select_gc = XCreateGC (dpy, item_window, 0, NULL);
-	
-	XDefineCursor(dpy, item_window, curs);
 
 	enterOnce = true;
 }
@@ -113,7 +108,6 @@ BaseMenu::~BaseMenu()
 
 	XDestroyWindow(dpy, item_window);
 	
-	XFreeCursor(dpy, curs);
 	XFreeFont(dpy, font);
 	
 	XFreeGC(dpy, gc);
