@@ -94,11 +94,7 @@ void Client::getXClientName()
 	
 	XFetchName(dpy, window, &name);
 		
-	if(name==NULL) 
-	{
-		name = "no name";
-	}
-	else
+	if(name) 
 	{
 		XTextExtents(wm->getFont(), name , strlen(name), 
 			&direction, &ascent, 
@@ -108,12 +104,6 @@ void Client::getXClientName()
 	}
 }
 
-// Set up a client structure for the new (not-yet-mapped) window. The
-// confusing bit is that we have to ignore 2 unmap events if the
-// client was already mapped but has IconicState set (for instance,
-// when we are the second window manager in a session).  That's
-// because there's one for the reparent (which happens on all viewable
-// windows) and then another for the unmapping itself. 
 void Client::makeNewClient(Window w)
 {
 	XWindowAttributes attr;
@@ -129,7 +119,6 @@ void Client::makeNewClient(Window w)
 	getXClientName();
 
 	XGetTransientForHint(dpy, window, &trans);
-
     	XGetWindowAttributes(dpy, window, &attr);
 
     	x = attr.x;
@@ -176,13 +165,10 @@ void Client::makeNewClient(Window w)
     	gravitate(APPLY_GRAVITY);
     	reparent();
 
-	if(belongs_to_desktop == -1)
-        {
-		belongs_to_desktop = wm->getCurrentDesktop();
-        }
+	belongs_to_desktop = wm->getCurrentDesktop();
 	
 	if (wm->getWMState(window) == IconicState) iconify();
-	else //if (wm->getWMState(window) == NormalState || wm->getWMState(window) == WithdrawnState)
+	else 
 	{
 		unhide();
 	
@@ -209,7 +195,8 @@ void Client::removeClient()
 	XDestroyWindow(dpy, title);
 	XDestroyWindow(dpy, frame);
 	
-	if (name) XFree(name);
+	if ( name ) XFree(name);
+
 	if (size) XFree(size);
 
     	XSync(dpy, False);
@@ -220,22 +207,18 @@ void Client::removeClient()
 	wm->removeClient(this);
 }
 
-// For a regular window, trans is None (false), and we include
-// enough space to draw the title. For a transient window we just make
-// a tiny strip. 
 int Client::theight()
 {
    	if (!has_title) return 0;
 	
 	int title_size = wm->getFont()->ascent + wm->getFont()->descent + SPACE;
 	
-	if(trans) return TRANSIENT_WINDOW_HEIGHT; // size for transient titlebar heights not to big, not too small
+	if(trans) return TRANSIENT_WINDOW_HEIGHT;
 	else
 		return title_size;
 	
 }
 
-// This is called whenever we update our Client stuff. 
 void Client::sendConfig()
 {
     	XConfigureEvent ce;
@@ -296,14 +279,7 @@ void Client::redraw()
 		}
 	}
 }
-
-// Window gravity is a mess to explain, but we don't need to do much
-// about it since we're using X borders. For NorthWest et al, the top
-// left corner of the window when there is no WM needs to match up
-// with the top left of our fram once we manage it, and likewise with
-// SouthWest and the bottom right (these are the only values I ever
-// use, but the others should be obvious.) Our titlebar is on the top
-// so we only have to adjust in the first case. 
+ 
 void Client::gravitate(int multiplier)
 {
     	int dy = 0;
@@ -320,13 +296,6 @@ void Client::gravitate(int multiplier)
    	y += multiplier * dy;
 }
 
-/* Well, the man pages for the shape extension say nothing, but I was
- * able to find a shape.PS.Z on the x.org FTP site. What we want to do
- * here is make the window shape be a boolean OR (or union, if you
- * prefer) of the client's shape and our titlebar. The titlebar
- * requires both a bound and a clip because it has a border -- the X
- * server will paint the border in the region between the two. (I knew
- * that using X borders would get me eventually... ;-)) */
 #ifdef SHAPE
 void Client::setShape()
 {
@@ -437,29 +406,6 @@ void Client::unhide()
 	} 	
 }
 
-// This function sets up the initial position of windows when they are mapped
-// for the first time. It still needs some work done to it to make it more 
-// aware of _NET_WM_STRUT's
-// 
-//
-//	XSizeHints structure definition
-// 
-// 	typedef struct {
-//            long flags;
-//            int x, y;
-//            int width, height;
-//            int min_width, min_height;
-//            int max_width, max_height;
-//            int width_inc, height_inc;
-//            struct {
-//                   int x;
-//                   int y;
-//            } min_aspect, max_aspect;
-//            int base_width, base_height;
-//            int win_gravity;
-//
-//       } XSizeHints;
-//
 void Client::initPosition()
 {
     	int mouse_x, mouse_y;
@@ -544,9 +490,6 @@ void Client::maximize()
 		old_width=width;
 		old_height=height;
 
-		// Check to see if this client sets
-		// its max size property. If so don't
-		// maximize it past that size.
 		if (size->flags & PMaxSize) {
 			
 			width = size->max_width;
@@ -558,11 +501,11 @@ void Client::maximize()
 	
 			x=0;
 			y=0;
-			width=xres;
-			height=yres;
+			width=xres-2;
+			height=yres-2;
 		
 			XMoveResizeWindow(dpy, frame, x, y, width, height);
-
+			
 			y = theight();
 			height -= theight();
 		}
@@ -718,10 +661,6 @@ void Client::drawOutline()
     	}
 }
 
-// If the window in question has a ResizeInc int, then it wants to be
-// resized in multiples of some (x,y). Here we set x_ret and y_ret to
-// the number of multiples (if mode == INCREMENTS) or the correct size
-// in pixels for said multiples (if mode == PIXELS). 
 int Client::getIncsize(int *x_ret, int *y_ret, int mode)
 {
     	int basex, basey;
@@ -751,7 +690,6 @@ int Client::getIncsize(int *x_ret, int *y_ret, int mode)
     return 0;
 }
 
-// This function makes it so only the titlebar shows.
 void Client::shade()
 {
 	raise();
@@ -766,17 +704,6 @@ void Client::shade()
 	}
 }
 
-// Because we are redirecting the root window, we get ConfigureRequest
-// events from both clients we're handling and ones that we aren't.
-// For clients we manage, we need to fiddle with the frame and the
-// client window, and for unmanaged windows we have to pass along
-// everything unchanged. Thankfully, we can reuse (a) the
-// XWindowChanges struct and () the code to configure the client
-// window in both cases.
-//
-// Most of the assignments here are going to be garbage, but only the
-// ones that are masked in by e->value_mask will be looked at by the X
-// server. 
 void Client::handleConfigureRequest(XConfigureRequestEvent *e)
 {
 	XWindowChanges wc;
@@ -804,12 +731,6 @@ void Client::handleConfigureRequest(XConfigureRequestEvent *e)
 		XMoveResizeWindow(dpy, window,0,theight(),width,height);
 	}
 
-	// If an app wants to place his window in a bogus position
-	// like offscreen then fix its position. Lets see if this
-	// works out okay. Warez and Porn sites have a bad habit
-	// of trying to place the Mozilla browser window titlebar
-	// just offscreen so you can't close the window. 
-	// The bastards!
 	if( (x + width > xres) 		|| 
 	    (height + theight() > yres) ||
 	    (x > xres)	 		|| 
@@ -823,7 +744,7 @@ void Client::handleConfigureRequest(XConfigureRequestEvent *e)
         if (e->value_mask & (CWWidth|CWHeight)) setShape();
 #endif
 
-	sendConfig();
+	//sendConfig();
 
 	if (e->value_mask & CWY) wc.x = 0;
 	if (e->value_mask & CWY) wc.y = theight();
@@ -846,17 +767,11 @@ void Client::handleUnmapEvent(XUnmapEvent *e)
 		delete this;
 }
 
-// This happens when a window is iconified and destroys itself. An
-// Unmap event wouldn't happen in that case because the window is
-// already unmapped. 
 void Client::handleDestroyEvent(XDestroyWindowEvent *e)
 {
 	delete this;
 }
 
-// If a client wants to iconify itself (boo! hiss!) it must send a
-// special kind of ClientMessage. We might set up other handlers here
-// but there's nothing else required by the ICCCM. 
 void Client::handleClientMessage(XClientMessageEvent *e)
 {	
 	if (e->message_type == wm->atom_wm_change_state &&
@@ -923,7 +838,6 @@ void Client::reparent()
         			CWOverrideRedirect|CWDontPropagate|CWBackPixel|CWBorderPixel|CWEventMask, 
 				&pattr);
 
-	// This window is used to house the window title and title bar button
 	title = XCreateWindow(dpy, 
 				frame,
         			0, 
@@ -944,7 +858,6 @@ void Client::reparent()
     	}
 	#endif
 
-	// We don't want these masks to be propagated down to the frame
 	XChangeWindowAttributes(dpy, window, CWDontPropagate, &pattr);
 
 	XSelectInput(dpy, window, FocusChangeMask|PropertyChangeMask);
@@ -1179,9 +1092,6 @@ void Client::handleColormapChange(XColormapEvent *e)
     	}
 }
 
-// If we were covered by multiple windows, we will usually get
-// multiple expose events, so ignore them unless e->count (the number
-// of outstanding exposes) is zero.
 void Client::handleExposeEvent(XExposeEvent *e)
 {
     	if (e->count == 0) redraw();
@@ -1201,19 +1111,11 @@ void Client::setDesktop(int desk)
 	if(belongs_to_desktop != wm->getCurrentDesktop())
 	{
 		hide();
+		wm->removeClientFromIconMenu(this);
 	}
 }
 
 void Client::raise()
 {
-	XWindowChanges wc;
-	wc.stack_mode = Above;
-	XConfigureWindow(dpy, frame, CWStackMode, &wc);
-}
-
-void Client::lower()
-{
-	XWindowChanges wc;
-	wc.stack_mode = Below;
-	XConfigureWindow(dpy, window, CWStackMode, &wc);
+	XRaiseWindow(dpy, frame);
 }
