@@ -14,16 +14,7 @@ KeySym WindowManager::alt_keys[]=
 			XK_Delete,
 			XK_End,
 			XK_Page_Up,
-			XK_Page_Down,
-			XK_1,
-			XK_2,
-			XK_3,
-			XK_4,
-			XK_5,
-			XK_6,
-			XK_7,
-			XK_8,
-			XK_9
+			XK_Page_Down
 };
 
 WindowManager::WindowManager(int argc, char** argv)
@@ -51,7 +42,6 @@ WindowManager::WindowManager(int argc, char** argv)
 void WindowManager::parseCommandLine(int argc, char** argv)
 {
 	// Make the default options equal something
-    	opt_font = DEF_FONT;
 	opt_fm = DEF_FM;
     	opt_fg = DEF_FG;
     	opt_fc = DEF_FC;
@@ -86,7 +76,6 @@ void WindowManager::parseCommandLine(int argc, char** argv)
 	// Get the args and test for different options
 	for (int i = 1; i < argc; i++) 
     	{
-        	OPT_STR("-fn", opt_font)
 	        OPT_STR("-fg", opt_fg)
         	OPT_STR("-bg", opt_bg)
 		OPT_STR("-fc", opt_fc)
@@ -112,7 +101,7 @@ void WindowManager::parseCommandLine(int argc, char** argv)
 		if(strcmp(argv[i], "-usage")==0) 
                 {
         		cerr << "usage: " << WINDOW_MANAGER_NAME << " [options]" << endl;
-	        	cerr << "   options are: -display <display>, -fn <font>, -fg|-bg|-bd <color>, " << endl;
+	        	cerr << "   options are: -display <display>, -fg|-bg|-bd <color>, " << endl;
         		cerr << "   -bw <width>, -md <max desktops>, -tj <left|center|right>, -wm <true|false>," << endl;
 			cerr << "    -new1|-new2 <cmd>, -fm (follow|sloppy|click), -wp (mouse|random), -usage, -help" << endl;
 			exit(0);
@@ -122,7 +111,6 @@ void WindowManager::parseCommandLine(int argc, char** argv)
                 {
                         cerr << "help: " << WINDOW_MANAGER_NAME << endl << endl;
                         cerr << "-display specifies a display to start the window manager on, The default is display :0." << endl;
-                        cerr << "-fn is the font which to use for displaying window title names, icon names and such." << endl;
                         cerr << "-fg, -bg and -bd are colors you wish the foreground, background and border to be for window titlebars." << endl;
                         cerr << "-bw is the border width of the window." << endl;
                         cerr << "-md is the number of maximum virtual desktops, the default is 4." << endl;
@@ -226,35 +214,30 @@ void WindowManager::goToDesktop(int d)
 	Window dummyw1, dummyw2, *wins;
 	Client* c;
 
-	if( (d < max_desktops) && (d >= 0) )
-	{
-		current_desktop = d;
+	setCurrentDesktop(d);
 
-		updateIconMenu();
-
-		XSetInputFocus(dpy, _button_proxy_win, RevertToNone, CurrentTime);
+	XSetInputFocus(dpy, _button_proxy_win, RevertToNone, CurrentTime);
 		
-		// Preserve stacking order
-		XQueryTree(dpy, root, &dummyw1, &dummyw2, &wins, &nwins);
-		for (i = 0; i < nwins; i++) 
-		{
-			c = findClient(wins[i]);
+	// Preserve stacking order
+	XQueryTree(dpy, root, &dummyw1, &dummyw2, &wins, &nwins);
+	for (i = 0; i < nwins; i++) 
+	{
+		c = findClient(wins[i]);
 				
-			if(c)
+		if(c)
+		{
+			if(c->belongsToWhichDesktop() == current_desktop)
 			{
-				if(c->belongsToWhichDesktop() == current_desktop)
-				{
-					if(! (c->isIconified())) 
-						c->unhide();
-				}
-				else {
-					if(! (c->isIconified())) 
-						c->hide();												
-				}
+				if(! (c->isIconified())) 
+				c->unhide();
+			}
+			else {
+				if(! (c->isIconified())) 
+				c->hide();												
 			}
 		}
-		XFree(wins);
 	}
+	XFree(wins);
 }
 
 void WindowManager::scanWins(void)
@@ -332,9 +315,8 @@ void WindowManager::setupDisplay()
 	XAllocNamedColor(dpy, DefaultColormap(dpy, screen), FOCUSED_BORDER_COLOR, &focused_border, &dummyc);
 	XAllocNamedColor(dpy, DefaultColormap(dpy, screen), UNFOCUSED_BORDER_COLOR, &unfocused_border, &dummyc);
         
-    	font = XLoadQueryFont(dpy, opt_font);
-    	if (!font) font = XLoadQueryFont(dpy, DEF_FONT);
-    	if (!font) { cerr << "DEF_FONT not found, aborting." << endl; exit(1); }
+    	font = XLoadQueryFont(dpy, DEF_FONT);
+    	if (!font) { cerr << "The default font cannot be found, exiting..." << endl; exit(1); }
 
 #ifdef SHAPE
     	shape = XShapeQueryExtension(dpy, &shape_event, &dummy);
@@ -536,14 +518,14 @@ void WindowManager::handleKeyPressEvent(XEvent *ev)
 			}			
 		break;
 	}
-	if (ks >= XK_1 && ks <= XK_1+(unsigned)max_desktops && ks - XK_1 <= (unsigned)9)  /* no two digit keys */
- 	{
-                if( (unsigned)current_desktop != ks - XK_1 )
-		{
-			(unsigned)current_desktop = ks - XK_1;
-			goToDesktop(current_desktop);
-		}
-	}
+	//if (ks >= XK_1 && ks <= XK_1+max_desktops && ks - XK_1 <= 9)  /* no two digit keys */
+ 	//{
+        //        if( current_desktop != ks - XK_1 )
+	//	{
+	//		current_desktop = ks - XK_1;
+	//		goToDesktop(current_desktop);
+	//	}
+	//}
 }
 
 void WindowManager::handleButtonPressEvent(XEvent *ev)
